@@ -48,8 +48,14 @@ export class MazeView extends DOMWidgetView {
   world_model: WorldModel;
 
   method_changed = () => {
-    let current_call: { method_name: string; params: any; cb: any } =
-      JSON.parse(this.model.get('current_call'));
+    let current_call: {
+      method_name: string;
+      params: any;
+      cb: any;
+      stats?: any;
+    } = JSON.parse(this.model.get('current_call'));
+
+    this.report_stats(current_call.stats);
 
     if (current_call.method_name === 'halt') {
       return this.halt();
@@ -121,6 +127,14 @@ export class MazeView extends DOMWidgetView {
     return this.world_model.robots[index]?.move_to(x, y);
   };
 
+  report_stats = (stats: any) => {
+    return (
+      this.world_model &&
+      this.world_model.update_stats &&
+      this.world_model.update_stats(stats)
+    );
+  };
+
   turn_left = (index: number) => {
     return this.world_model.robots[index]?.turn_left();
   };
