@@ -11,7 +11,7 @@ from functools import partial
 from .tile_map import DEFAULT_TILE_MAP
 
 
-from .goal import class_list, Goal, PositionGoal 
+from .goal import class_list, Goal, PositionGoal, DropGoal
 
 def cstr(s, color='black'):
     return "<text style=color:{}>{}</text>".format(color, s)
@@ -55,6 +55,7 @@ class Cell:
         self.y = y
         self.world = world
         self.background =  background
+        self.editable = {"pick": True, "drop": True}
     
     
     def walls_list(self, direction):
@@ -303,6 +304,19 @@ class WorldModel():
 
     def position_goal(self):
         return list(filter(lambda goal : isinstance(goal, PositionGoal), self.goals))
+    
+    def drop_goals(self):
+        return list(filter(lambda goal : isinstance(goal, DropGoal), self.goals))
+
+
+    
+    def drop_allowed(self, x,y, val=False):
+        cell = self.cells[x - 1][y - 1]
+        cell.editable["drop"] = val
+
+    def pick_allowed(self, x,y, val=False):
+        cell = self.cells[x - 1][y - 1]
+        cell.editable["pick"] = val
 
     def dimensions(self):
         return [self.rows, self.cols]
@@ -336,7 +350,8 @@ class WorldModel():
             self.objects,
             self.tilemap,
             self.tiles,
-            [x.msg() for x in self.goals]
+            [x.msg() for x in self.goals],
+            [{"obj_name": x.obj_name, "x": x.x, "y": x.y, "val": x.val} for x in self.drop_goals()]
         ])
 
 
