@@ -407,7 +407,7 @@ class Robot():
         --------
         >>> bot.take()
         """
-        if self.max_capacity is not None and self.max_capacity > len(self.last_picked):
+        if self.max_capacity is not None and self.max_capacity < len(self.last_picked):
             raise RuntimeError(f"Can't Carry more than {self.max_capacity} items")
 
         self.world_model.incr_instruction()
